@@ -12,14 +12,12 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-import functools
 import logging
 import random
 import uuid
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type, Union
 
 import pandas as pd
-from pkg_resources import parse_version
 
 from argilla.client.models import (
     Framework,
@@ -30,47 +28,17 @@ from argilla.client.models import (
     TokenClassificationRecord,
 )
 from argilla.client.sdk.datasets.models import TaskType
+from argilla.utils.dependency import require_version, requires_version
 from argilla.utils.span_utils import SpanUtils
 
+if TYPE_CHECKING:
+    import datasets
+    import pandas
+    import spacy
+
 _LOGGER = logging.getLogger(__name__)
 
 
-def _requires_datasets(func):
-    @functools.wraps(func)
-    def check_if_datasets_installed(*args, **kwargs):
-        try:
-            import datasets
-        except ModuleNotFoundError:
-            raise ModuleNotFoundError(
-                f"'datasets' must be installed to use `{func.__name__}`! You can"
-                " install 'datasets' with the command: `pip install datasets>1.17.0`"
-            )
-        if not (parse_version(datasets.__version__) > parse_version("1.17.0")):
-            raise ModuleNotFoundError(
-                "Version >1.17.0 of 'datasets' must be installed to use `to_datasets`!"
-                " You can update 'datasets' with the command: `pip install -U"
-                " datasets>1.17.0`"
-            )
-        return func(*args, **kwargs)
-
-    return check_if_datasets_installed
-
-
-def _requires_spacy(func):
-    @functools.wraps(func)
-    def check_if_spacy_installed(*args, **kwargs):
-        try:
-            import spacy
-        except ModuleNotFoundError:
-            raise ModuleNotFoundError(
-                f"'spacy' must be installed to use `{func.__name__}`"
-                "You can install 'spacy' with the command: `pip install spacy`"
-            )
-        return func(*args, **kwargs)
-
-    return check_if_spacy_installed
-
-
 class DatasetBase:
     """The Dataset classes are containers for argilla records.
 
@@ -98,9 +66,7 @@ class DatasetBase:
 
     def __init__(self, records: Optional[List[Record]] = None):
         if self._RECORD_TYPE is None:
-            raise NotImplementedError(
-                "A Dataset implementation has to define a `_RECORD_TYPE`!"
-            )
+            raise NotImplementedError("A Dataset implementation has to define a `_RECORD_TYPE`!")
 
         self._records = records or []
         if self._records:
@@ -153,7 +119,7 @@ class DatasetBase:
     def __str__(self):
         return repr(self)
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def to_datasets(self) -> "datasets.Dataset":
         """Exports your records to a `datasets.Dataset`.
 
@@ -174,8 +140,7 @@ class DatasetBase:
             del ds_dict["metadata"]
             dataset = datasets.Dataset.from_dict(ds_dict)
             _LOGGER.warning(
-                "The 'metadata' of the records were removed, since it was incompatible"
-                " with the 'datasets' format."
+                "The 'metadata' of the records were removed, since it was incompatible" " with the 'datasets' format."
             )
 
         return dataset
@@ -215,15 +180,10 @@ class DatasetBase:
         import datasets
 
         if isinstance(dataset, datasets.DatasetDict):
-            raise ValueError(
-                "`datasets.DatasetDict` are not supported. Please, select the dataset"
-                " split before."
-            )
+            raise ValueError("`datasets.DatasetDict` are not supported. Please, select the dataset" " split before.")
 
         # clean column mappings
-        column_mapping = {
-            key: val for key, val in column_mapping.items() if val is not None
-        }
+        column_mapping = {key: val for key, val in column_mapping.items() if val is not None}
 
         cols_to_be_renamed, cols_to_be_joined = {}, {}
         for field, col in column_mapping.items():
@@ -257,9 +217,7 @@ class DatasetBase:
             The dataset with unsupported columns removed.
         """
         not_supported_columns = [
-            col
-            for col in dataset.column_names
-            if col not in cls._record_init_args() + extra_columns
+            col for col in dataset.column_names if col not in cls._record_init_args() + extra_columns
         ]
 
         if not_supported_columns:
@@ -273,9 +231,7 @@ class DatasetBase:
         return dataset
 
     @staticmethod
-    def _join_datasets_columns_and_delete(
-        row: Dict[str, Any], columns: List[str]
-    ) -> Dict[str, Any]:
+    def _join_datasets_columns_and_delete(row: Dict[str, Any], columns: List[str]) -> Dict[str, Any]:
         """Joins columns of a `datasets.Dataset` row into a dict, and deletes the single columns.
 
         Updates the ``row`` dictionary!
@@ -348,9 +304,7 @@ class DatasetBase:
         Returns:
             The imported records in a argilla Dataset.
         """
-        not_supported_columns = [
-            col for col in dataframe.columns if col not in cls._record_init_args()
-        ]
+        not_supported_columns = [col for col in dataframe.columns if col not in cls._record_init_args()]
         if not_supported_columns:
             _LOGGER.warning(
                 "Following columns are not supported by the"
@@ -455,14 +409,10 @@ class DatasetBase:
         )
 
         # check if train sizes sum up to 1
-        assert (train_size + test_size) == 1, ValueError(
-            "`train_size` and `test_size` must sum to 1."
-        )
+        assert (train_size + test_size) == 1, ValueError("`train_size` and `test_size` must sum to 1.")
 
         # check for annotations
-        assert any([rec.annotation for rec in self._records]), ValueError(
-            "Dataset has no annotations."
-        )
+        assert any([rec.annotation for rec in self._records]), ValueError("Dataset has no annotations.")
 
         # shuffle records
         shuffled_records = self._records.copy()
@@ -478,16 +428,14 @@ class DatasetBase:
 
         # prepare for training for the right method
         if framework is Framework.TRANSFORMERS:
-            return self._prepare_for_training_with_transformers(
-                train_size=train_size, test_size=test_size, seed=seed
-            )
+            return self._prepare_for_training_with_transformers(train_size=train_size, test_size=test_size, seed=seed)
         elif framework is Framework.SPACY and lang is None:
             raise ValueError(
-                "Please provide a spacy language model to prepare the dataset for"
-                " training with the spacy framework."
+                "Please provide a spacy language model to prepare the" " dataset for training with the spacy framework."
             )
         elif framework in [Framework.SPACY, Framework.SPARK_NLP]:
             if train_size and test_size:
+                require_version("scikit-learn")
                 from sklearn.model_selection import train_test_split
 
                 records_train, records_test = train_test_split(
@@ -497,12 +445,8 @@ class DatasetBase:
                     random_state=seed,
                 )
                 if framework is Framework.SPACY:
-                    train_docbin = self._prepare_for_training_with_spacy(
-                        nlp=lang, records=records_train
-                    )
-                    test_docbin = self._prepare_for_training_with_spacy(
-                        nlp=lang, records=records_test
-                    )
+                    train_docbin = self._prepare_for_training_with_spacy(nlp=lang, records=records_train)
+                    test_docbin = self._prepare_for_training_with_spacy(nlp=lang, records=records_test)
                     return train_docbin, test_docbin
                 else:
                     train_df = self._prepare_for_training_with_spark_nlp(records_train)
@@ -511,20 +455,13 @@ class DatasetBase:
                     return train_df, test_df
             else:
                 if framework is Framework.SPACY:
-                    return self._prepare_for_training_with_spacy(
-                        nlp=lang, records=shuffled_records
-                    )
+                    return self._prepare_for_training_with_spacy(nlp=lang, records=shuffled_records)
                 else:
-                    return self._prepare_for_training_with_spark_nlp(
-                        records=shuffled_records
-                    )
+                    return self._prepare_for_training_with_spark_nlp(records=shuffled_records)
         else:
-            raise NotImplementedError(
-                f"Framework {framework} is not supported. Choose from:"
-                f" {list(Framework)}"
-            )
+            raise NotImplementedError(f"Framework {framework} is not supported. Choose from:" f" {list(Framework)}")
 
-    @_requires_spacy
+    @requires_version("spacy")
     def _prepare_for_training_with_spacy(
         self, **kwargs
     ) -> Union["spacy.token.DocBin", Tuple["spacy.token.DocBin", "spacy.token.DocBin"]]:
@@ -539,7 +476,7 @@ class DatasetBase:
 
         raise NotImplementedError
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def _prepare_for_training_with_transformers(self, **kwargs) -> "datasets.Dataset":
         """Prepares the dataset for training using the "transformers" framework.
 
@@ -552,7 +489,7 @@ class DatasetBase:
 
         raise NotImplementedError
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def _prepare_for_training_with_spark_nlp(self, **kwargs) -> "datasets.Dataset":
         """Prepares the dataset for training using the "spark-nlp" framework.
 
@@ -621,6 +558,7 @@ class DatasetForTextClassification(DatasetBase):
         super().__init__(records=records)
 
     @classmethod
+    @requires_version("datasets>1.17.0")
     def from_datasets(
         cls,
         dataset: "datasets.Dataset",
@@ -668,9 +606,7 @@ class DatasetForTextClassification(DatasetBase):
 
         records = []
         for row in dataset:
-            row["inputs"] = cls._parse_inputs_field(
-                row, cols_to_be_joined.get("inputs")
-            )
+            row["inputs"] = cls._parse_inputs_field(row, cols_to_be_joined.get("inputs"))
             if row.get("inputs") is not None and row.get("text") is not None:
                 del row["text"]
 
@@ -695,10 +631,7 @@ class DatasetForTextClassification(DatasetBase):
             if row.get("explanation"):
                 row["explanation"] = (
                     {
-                        key: [
-                            TokenAttributions(**tokattr_kwargs)
-                            for tokattr_kwargs in val
-                        ]
+                        key: [TokenAttributions(**tokattr_kwargs) for tokattr_kwargs in val]
                         for key, val in row["explanation"].items()
                     }
                     if row["explanation"] is not None
@@ -706,9 +639,7 @@ class DatasetForTextClassification(DatasetBase):
                 )
 
             if cols_to_be_joined.get("metadata"):
-                row["metadata"] = cls._join_datasets_columns_and_delete(
-                    row, cols_to_be_joined["metadata"]
-                )
+                row["metadata"] = cls._join_datasets_columns_and_delete(row, cols_to_be_joined["metadata"])
 
             records.append(TextClassificationRecord.parse_obj(row))
 
@@ -760,18 +691,13 @@ class DatasetForTextClassification(DatasetBase):
                 ]
             elif key == "explanation":
                 ds_dict[key] = [
-                    {
-                        key: list(map(dict, tokattrs))
-                        for key, tokattrs in rec.explanation.items()
-                    }
+                    {key: list(map(dict, tokattrs)) for key, tokattrs in rec.explanation.items()}
                     if rec.explanation is not None
                     else None
                     for rec in self._records
                 ]
             elif key == "id":
-                ds_dict[key] = [
-                    None if rec.id is None else str(rec.id) for rec in self._records
-                ]
+                ds_dict[key] = [None if rec.id is None else str(rec.id) for rec in self._records]
             elif key == "metadata":
                 ds_dict[key] = [getattr(rec, key) or None for rec in self._records]
             else:
@@ -781,11 +707,9 @@ class DatasetForTextClassification(DatasetBase):
 
     @classmethod
     def _from_pandas(cls, dataframe: pd.DataFrame) -> "DatasetForTextClassification":
-        return cls(
-            [TextClassificationRecord(**row) for row in dataframe.to_dict("records")]
-        )
+        return cls([TextClassificationRecord(**row) for row in dataframe.to_dict("records")])
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def _prepare_for_training_with_transformers(
         self,
         train_size: Optional[float] = None,
@@ -794,12 +718,7 @@ class DatasetForTextClassification(DatasetBase):
     ):
         import datasets
 
-        inputs_keys = {
-            key: None
-            for rec in self._records
-            for key in rec.inputs
-            if rec.annotation is not None
-        }.keys()
+        inputs_keys = {key: None for rec in self._records for key in rec.inputs if rec.annotation is not None}.keys()
 
         ds_dict = {**{key: [] for key in inputs_keys}, "label": []}
         for rec in self._records:
@@ -826,11 +745,10 @@ class DatasetForTextClassification(DatasetBase):
             "label": [class_label] if self._records[0].multi_label else class_label,
         }
 
-        ds = datasets.Dataset.from_dict(
-            ds_dict, features=datasets.Features(feature_dict)
-        )
+        ds = datasets.Dataset.from_dict(ds_dict, features=datasets.Features(feature_dict))
 
         if self._records[0].multi_label:
+            require_version("scikit-learn")
             from sklearn.preprocessing import MultiLabelBinarizer
 
             labels = [rec["label"] for rec in ds]
@@ -847,16 +765,12 @@ class DatasetForTextClassification(DatasetBase):
                 features=datasets.Features(feature_dict),
             )
         if test_size is not None and test_size != 0:
-            ds = ds.train_test_split(
-                train_size=train_size, test_size=test_size, seed=seed
-            )
+            ds = ds.train_test_split(train_size=train_size, test_size=test_size, seed=seed)
 
         return ds
 
-    @_requires_spacy
-    def _prepare_for_training_with_spacy(
-        self, nlp: "spacy.Language", records: List[Record]
-    ) -> "spacy.tokens.DocBin":
+    @requires_version("spacy")
+    def _prepare_for_training_with_spacy(self, nlp: "spacy.Language", records: List[Record]) -> "spacy.tokens.DocBin":
         from spacy.tokens import DocBin
 
         db = DocBin()
@@ -875,17 +789,19 @@ class DatasetForTextClassification(DatasetBase):
             doc = nlp.make_doc(text)
 
             cats = dict.fromkeys(all_labels, 0)
-            for anno in record.annotation:
-                cats[anno] = 1
+
+            if isinstance(record.annotation, list):
+                for anno in record.annotation:
+                    cats[anno] = 1
+            else:
+                cats[record.annotation] = 1
 
             doc.cats = cats
             db.add(doc)
 
         return db
 
-    def _prepare_for_training_with_spark_nlp(
-        self, records: List[Record]
-    ) -> "pandas.DataFrame":
+    def _prepare_for_training_with_spark_nlp(self, records: List[Record]) -> "pandas.DataFrame":
         if records[0].multi_label:
             label_name = "labels"
         else:
@@ -909,8 +825,15 @@ class DatasetForTextClassification(DatasetBase):
     def __all_labels__(self):
         all_labels = set()
         for record in self._records:
-            if record.annotation:
-                all_labels.update(record.annotation)
+            if record.annotation is None:
+                continue
+            elif isinstance(record.annotation, str):
+                all_labels.add(record.annotation)
+            elif isinstance(record.annotation, list):
+                all_labels.update((tuple(record.annotation)))
+            else:
+                # this is highly unlikely
+                raise TypeError("Record.annotation contains an unsupported type: {}".format(type(record.annotation)))
 
         return list(all_labels)
 
@@ -956,6 +879,7 @@ class DatasetForTokenClassification(DatasetBase):
         return parent_fields + ["tags"]  # compute annotation from tags
 
     @classmethod
+    @requires_version("datasets>1.17.0")
     def from_datasets(
         cls,
         dataset: "datasets.Dataset",
@@ -1010,9 +934,7 @@ class DatasetForTokenClassification(DatasetBase):
                 continue
 
             if row.get("tags"):
-                row["tags"] = cls._parse_datasets_column_with_classlabel(
-                    row["tags"], dataset.features["tags"]
-                )
+                row["tags"] = cls._parse_datasets_column_with_classlabel(row["tags"], dataset.features["tags"])
 
             if row.get("prediction"):
                 row["prediction"] = cls.__entities_to_tuple__(row["prediction"])
@@ -1021,9 +943,7 @@ class DatasetForTokenClassification(DatasetBase):
                 row["annotation"] = cls.__entities_to_tuple__(row["annotation"])
 
             if cols_to_be_joined.get("metadata"):
-                row["metadata"] = cls._join_datasets_columns_and_delete(
-                    row, cols_to_be_joined["metadata"]
-                )
+                row["metadata"] = cls._join_datasets_columns_and_delete(row, cols_to_be_joined["metadata"])
 
             records.append(TokenClassificationRecord.parse_obj(row))
 
@@ -1037,7 +957,7 @@ class DatasetForTokenClassification(DatasetBase):
     ) -> "DatasetForTokenClassification":
         return super().from_pandas(dataframe)
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def _prepare_for_training_with_transformers(
         self,
         train_size: Optional[float] = None,
@@ -1056,13 +976,7 @@ class DatasetForTokenClassification(DatasetBase):
             return datasets.Dataset.from_dict({})
 
         class_tags = ["O"]
-        class_tags.extend(
-            [
-                f"{pre}-{label}"
-                for label in sorted(self.__all_labels__())
-                for pre in ["B", "I"]
-            ]
-        )
+        class_tags.extend([f"{pre}-{label}" for label in sorted(self.__all_labels__()) for pre in ["B", "I"]])
         class_tags = datasets.ClassLabel(names=class_tags)
 
         def spans2iob(example):
@@ -1072,27 +986,19 @@ class DatasetForTokenClassification(DatasetBase):
 
             return class_tags.str2int(tags)
 
-        ds = (
-            self.to_datasets()
-            .filter(self.__only_annotations__)
-            .map(lambda example: {"ner_tags": spans2iob(example)})
-        )
+        ds = self.to_datasets().filter(self.__only_annotations__).map(lambda example: {"ner_tags": spans2iob(example)})
         new_features = ds.features.copy()
         new_features["ner_tags"] = datasets.Sequence(feature=class_tags)
         ds = ds.cast(new_features)
         ds = ds.remove_columns(set(ds.column_names) - set(["tokens", "ner_tags"]))
 
         if test_size is not None and test_size != 0:
-            ds = ds.train_test_split(
-                train_size=train_size, test_size=test_size, seed=seed
-            )
+            ds = ds.train_test_split(train_size=train_size, test_size=test_size, seed=seed)
 
         return ds
 
-    @_requires_spacy
-    def _prepare_for_training_with_spacy(
-        self, nlp: "spacy.Language", records: List[Record]
-    ) -> "spacy.tokens.DocBin":
+    @requires_version("spacy")
+    def _prepare_for_training_with_spacy(self, nlp: "spacy.Language", records: List[Record]) -> "spacy.tokens.DocBin":
         from spacy.tokens import DocBin
 
         db = DocBin()
@@ -1123,9 +1029,7 @@ class DatasetForTokenClassification(DatasetBase):
 
         return db
 
-    def _prepare_for_training_with_spark_nlp(
-        self, records: List[Record]
-    ) -> "pandas.DataFrame":
+    def _prepare_for_training_with_spark_nlp(self, records: List[Record]) -> "pandas.DataFrame":
         for record in records:
             if record.id is None:
                 record.id = str(uuid.uuid4())
@@ -1158,9 +1062,7 @@ class DatasetForTokenClassification(DatasetBase):
 
         # create a dict first, where we make the necessary transformations
         def entities_to_dict(
-            entities: Optional[
-                List[Union[Tuple[str, int, int, float], Tuple[str, int, int]]]
-            ]
+            entities: Optional[List[Union[Tuple[str, int, int, float], Tuple[str, int, int]]]]
         ) -> Optional[List[Dict[str, Union[str, int, float]]]]:
             if entities is None:
                 return None
@@ -1174,17 +1076,11 @@ class DatasetForTokenClassification(DatasetBase):
         ds_dict = {}
         for key in self._RECORD_TYPE.__fields__:
             if key == "prediction":
-                ds_dict[key] = [
-                    entities_to_dict(rec.prediction) for rec in self._records
-                ]
+                ds_dict[key] = [entities_to_dict(rec.prediction) for rec in self._records]
             elif key == "annotation":
-                ds_dict[key] = [
-                    entities_to_dict(rec.annotation) for rec in self._records
-                ]
+                ds_dict[key] = [entities_to_dict(rec.annotation) for rec in self._records]
             elif key == "id":
-                ds_dict[key] = [
-                    None if rec.id is None else str(rec.id) for rec in self._records
-                ]
+                ds_dict[key] = [None if rec.id is None else str(rec.id) for rec in self._records]
             elif key == "metadata":
                 ds_dict[key] = [getattr(rec, key) or None for rec in self._records]
             else:
@@ -1205,9 +1101,7 @@ class DatasetForTokenClassification(DatasetBase):
 
     @classmethod
     def _from_pandas(cls, dataframe: pd.DataFrame) -> "DatasetForTokenClassification":
-        return cls(
-            [TokenClassificationRecord(**row) for row in dataframe.to_dict("records")]
-        )
+        return cls([TokenClassificationRecord(**row) for row in dataframe.to_dict("records")])
 
 
 @_prepend_docstring(Text2TextRecord)
@@ -1244,6 +1138,7 @@ class DatasetForText2Text(DatasetBase):
         super().__init__(records=records)
 
     @classmethod
+    @requires_version("datasets>1.17.0")
     def from_datasets(
         cls,
         dataset: "datasets.Dataset",
@@ -1294,9 +1189,7 @@ class DatasetForText2Text(DatasetBase):
                 row["prediction"] = cls._parse_prediction_field(row["prediction"])
 
             if cols_to_be_joined.get("metadata"):
-                row["metadata"] = cls._join_datasets_columns_and_delete(
-                    row, cols_to_be_joined["metadata"]
-                )
+                row["metadata"] = cls._join_datasets_columns_and_delete(row, cols_to_be_joined["metadata"])
 
             records.append(Text2TextRecord.parse_obj(row))
 
@@ -1332,15 +1225,11 @@ class DatasetForText2Text(DatasetBase):
         for key in self._RECORD_TYPE.__fields__:
             if key == "prediction":
                 ds_dict[key] = [
-                    [pred_to_dict(pred) for pred in rec.prediction]
-                    if rec.prediction is not None
-                    else None
+                    [pred_to_dict(pred) for pred in rec.prediction] if rec.prediction is not None else None
                     for rec in self._records
                 ]
             elif key == "id":
-                ds_dict[key] = [
-                    None if rec.id is None else str(rec.id) for rec in self._records
-                ]
+                ds_dict[key] = [None if rec.id is None else str(rec.id) for rec in self._records]
             elif key == "metadata":
                 ds_dict[key] = [getattr(rec, key) or None for rec in self._records]
             else:
@@ -1352,7 +1241,7 @@ class DatasetForText2Text(DatasetBase):
     def _from_pandas(cls, dataframe: pd.DataFrame) -> "DatasetForText2Text":
         return cls([Text2TextRecord(**row) for row in dataframe.to_dict("records")])
 
-    @_requires_datasets
+    @requires_version("datasets>1.17.0")
     def _prepare_for_training_with_transformers(
         self,
         train_size: Optional[float] = None,
@@ -1373,26 +1262,31 @@ class DatasetForText2Text(DatasetBase):
             "target": datasets.Value("string"),
         }
 
-        ds = datasets.Dataset.from_dict(
-            ds_dict, features=datasets.Features(feature_dict)
-        )
+        ds = datasets.Dataset.from_dict(ds_dict, features=datasets.Features(feature_dict))
 
         if test_size is not None and test_size != 0:
-            ds = ds.train_test_split(
-                train_size=train_size, test_size=test_size, seed=seed
-            )
+            ds = ds.train_test_split(train_size=train_size, test_size=test_size, seed=seed)
 
         return ds
 
+    def _prepare_for_training_with_spark_nlp(self, records: List[Record]) -> "pandas.DataFrame":
+        spark_nlp_data = []
+        for record in records:
+            if record.annotation is None:
+                continue
+            if record.id is None:
+                record.id = str(uuid.uuid4())
+            text = record.text
 
-Dataset = Union[
-    DatasetForTextClassification, DatasetForTokenClassification, DatasetForText2Text
-]
+            spark_nlp_data.append([record.id, text, record.annotation])
+
+        return pd.DataFrame(spark_nlp_data, columns=["id", "text", "target"])
 
 
-def read_datasets(
-    dataset: "datasets.Dataset", task: Union[str, TaskType], **kwargs
-) -> Dataset:
+Dataset = Union[DatasetForTextClassification, DatasetForTokenClassification, DatasetForText2Text]
+
+
+def read_datasets(dataset: "datasets.Dataset", task: Union[str, TaskType], **kwargs) -> Dataset:
     """Reads a datasets Dataset and returns a argilla Dataset
 
     Args:
@@ -1445,9 +1339,8 @@ def read_datasets(
         return DatasetForTokenClassification.from_datasets(dataset, **kwargs)
     if task is TaskType.text2text:
         return DatasetForText2Text.from_datasets(dataset, **kwargs)
-    raise NotImplementedError(
-        "Reading a datasets Dataset is not implemented for the given task!"
-    )
+
+    raise NotImplementedError("Reading a datasets Dataset is not implemented for the given task!")
 
 
 def read_pandas(dataframe: pd.DataFrame, task: Union[str, TaskType]) -> Dataset:
@@ -1502,9 +1395,7 @@ def read_pandas(dataframe: pd.DataFrame, task: Union[str, TaskType]) -> Dataset:
         return DatasetForTokenClassification.from_pandas(dataframe)
     if task is TaskType.text2text:
         return DatasetForText2Text.from_pandas(dataframe)
-    raise NotImplementedError(
-        "Reading a pandas DataFrame is not implemented for the given task!"
-    )
+    raise NotImplementedError("Reading a pandas DataFrame is not implemented for the given task!")
 
 
 class WrongRecordTypeError(Exception):
