@@ -12,7 +12,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-from typing import Dict, List, Optional, Union
+from typing import List, Optional, Union
 
 import httpx
 
@@ -43,7 +43,6 @@ def data(
     limit: Optional[int] = None,
     id_from: Optional[str] = None,
 ) -> Response[Union[List[TextClassificationRecord], HTTPValidationError, ErrorMessage]]:
-
     path = f"/api/datasets/{name}/TextClassification/data"
     params = build_param_dict(id_from, limit)
 
@@ -53,9 +52,7 @@ def data(
         params=params if params else None,
         json=request.dict() if request else {},
     ) as response:
-        return build_data_response(
-            response=response, data_type=TextClassificationRecord
-        )
+        return build_data_response(response=response, data_type=TextClassificationRecord)
 
 
 def add_dataset_labeling_rule(
@@ -63,9 +60,7 @@ def add_dataset_labeling_rule(
     name: str,
     rule: LabelingRule,
 ) -> Response[Union[LabelingRule, HTTPValidationError, ErrorMessage]]:
-    url = "{}/api/datasets/{name}/TextClassification/labeling/rules".format(
-        client.base_url, name=name
-    )
+    url = "{}/api/datasets/{name}/TextClassification/labeling/rules".format(client.base_url, name=name)
 
     response = httpx.post(
         url=url,
@@ -119,10 +114,7 @@ def fetch_dataset_labeling_rules(
     client: AuthenticatedClient,
     name: str,
 ) -> Response[Union[List[LabelingRule], HTTPValidationError, ErrorMessage]]:
-
-    url = "{}/api/datasets/TextClassification/{name}/labeling/rules".format(
-        client.base_url, name=name
-    )
+    url = "{}/api/datasets/TextClassification/{name}/labeling/rules".format(client.base_url, name=name)
 
     response = httpx.get(
         url=url,
@@ -140,7 +132,6 @@ def dataset_rule_metrics(
     query: str,
     label: str,
 ) -> Response[Union[LabelingRuleMetricsSummary, HTTPValidationError, ErrorMessage]]:
-
     url = "{}/api/datasets/TextClassification/{name}/labeling/rules/{query}/metrics?label={label}".format(
         client.base_url, name=name, query=query, label=label
     )
@@ -152,6 +143,4 @@ def dataset_rule_metrics(
         timeout=client.get_timeout(),
     )
 
-    return build_typed_response(
-        response, response_type_class=LabelingRuleMetricsSummary
-    )
+    return build_typed_response(response, response_type_class=LabelingRuleMetricsSummary)
