@@ -27,7 +27,6 @@ from argilla.server.apis.v0.models.commons.params import (
 )
 from argilla.server.apis.v0.models.text2text import (
     Text2TextBulkRequest,
-    Text2TextDataset,
     Text2TextMetrics,
     Text2TextQuery,
     Text2TextRecord,
@@ -40,9 +39,10 @@ from argilla.server.commons.models import TaskType
 from argilla.server.errors import EntityNotFoundError
 from argilla.server.helpers import takeuntil
 from argilla.server.responses import StreamingResponseWithErrorHandling
+from argilla.server.schemas.datasets import CreateDatasetRequest
 from argilla.server.security import auth
 from argilla.server.security.model import User
-from argilla.server.services.datasets import DatasetsService
+from argilla.server.services.datasets import DatasetsService, ServiceBaseDataset
 from argilla.server.services.tasks.text2text import Text2TextService
 from argilla.server.services.tasks.text2text.models import (
     ServiceText2TextQuery,
@@ -56,7 +56,6 @@ def configure_router():
 
     TasksFactory.register_task(
         task_type=TaskType.text2text,
-        dataset_class=Text2TextDataset,
         query_request=Text2TextQuery,
         record_class=ServiceText2TextRecord,
         metrics=Text2TextMetrics,
@@ -78,16 +77,14 @@ def configure_router():
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> BulkResponse:
-
         task = task_type
-        owner = current_user.check_workspace(common_params.workspace)
+        workspace = current_user.check_workspace(common_params.workspace)
         try:
             dataset = datasets.find_by_name(
                 current_user,
                 name=name,
                 task=task,
-                workspace=owner,
-                as_dataset_class=TasksFactory.get_task_dataset(task_type),
+                workspace=workspace,
             )
             datasets.update(
                 user=current_user,
@@ -96,10 +93,8 @@ def configure_router():
                 metadata=bulk.metadata,
             )
         except EntityNotFoundError:
-            dataset_class = TasksFactory.get_task_dataset(task)
-            dataset = dataset_class.parse_obj({**bulk.dict(), "name": name})
-            dataset.owner = owner
-            datasets.create_dataset(user=current_user, dataset=dataset)
+            dataset = CreateDatasetRequest(name=name, workspace=workspace, task=task, **bulk.dict())
+            dataset = datasets.create_dataset(user=current_user, dataset=dataset)
 
         result = await service.add_records(
             dataset=dataset,
@@ -121,15 +116,12 @@ def configure_router():
         name: str,
         search: Text2TextSearchRequest = None,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        include_metrics: bool = Query(
-            False, description="If enabled, return related record metrics"
-        ),
+        include_metrics: bool = Query(False, description="If enabled, return related record metrics"),
         pagination: RequestPagination = Depends(),
         service: Text2TextService = Depends(Text2TextService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> Text2TextSearchResults:
-
         search = search or Text2TextSearchRequest()
         query = search.query or Text2TextQuery()
         dataset = datasets.find_by_name(
@@ -137,7 +129,6 @@ def configure_router():
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
         )
         result = service.search(
             dataset=dataset,
@@ -151,9 +142,7 @@ def configure_router():
         return Text2TextSearchResults(
             total=result.total,
             records=[Text2TextRecord.parse_obj(r) for r in result.records],
-            aggregations=Text2TextSearchAggregations.parse_obj(result.metrics)
-            if result.metrics
-            else None,
+            aggregations=Text2TextSearchAggregations.parse_obj(result.metrics) if result.metrics else None,
         )
 
     def scan_data_response(
@@ -185,9 +174,7 @@ def configure_router():
                     )
                 ) + "\n"
 
-        return StreamingResponseWithErrorHandling(
-            stream_generator(data_stream), media_type="application/json"
-        )
+        return StreamingResponseWithErrorHandling(stream_generator(data_stream), media_type="application/json")
 
     @router.post(
         path=f"{base_endpoint}/data",
@@ -233,7 +220,6 @@ def configure_router():
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
         )
         data_stream = map(
             Text2TextRecord.parse_obj,
