@@ -49,6 +49,7 @@ from argilla.server.commons.models import TaskType
 from argilla.server.errors import EntityNotFoundError
 from argilla.server.helpers import takeuntil
 from argilla.server.responses import StreamingResponseWithErrorHandling
+from argilla.server.schemas.datasets import CreateDatasetRequest
 from argilla.server.security import auth
 from argilla.server.security.model import User
 from argilla.server.services.datasets import DatasetsService
@@ -89,41 +90,33 @@ def configure_router():
         name: str,
         bulk: TextClassificationBulkRequest,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         validator: DatasetValidator = Depends(DatasetValidator.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> BulkResponse:
-
         task = task_type
-        owner = current_user.check_workspace(common_params.workspace)
+        workspace = current_user.check_workspace(common_params.workspace)
         try:
             dataset = datasets.find_by_name(
                 current_user,
                 name=name,
                 task=task,
-                workspace=owner,
-                as_dataset_class=TasksFactory.get_task_dataset(task_type),
+                workspace=workspace,
             )
-            datasets.update(
+            dataset = datasets.update(
                 user=current_user,
                 dataset=dataset,
                 tags=bulk.tags,
                 metadata=bulk.metadata,
             )
         except EntityNotFoundError:
-            dataset_class = TasksFactory.get_task_dataset(task)
-            dataset = dataset_class.parse_obj({**bulk.dict(), "name": name})
-            dataset.owner = owner
-            datasets.create_dataset(user=current_user, dataset=dataset)
+            dataset = CreateDatasetRequest(name=name, workspace=workspace, task=task, **bulk.dict())
+            dataset = datasets.create_dataset(user=current_user, dataset=dataset)
 
         # TODO(@frascuchon): Validator should be applied in the service layer
         records = [ServiceTextClassificationRecord.parse_obj(r) for r in bulk.records]
-        await validator.validate_dataset_records(
-            user=current_user, dataset=dataset, records=records
-        )
+        await validator.validate_dataset_records(user=current_user, dataset=dataset, records=records)
 
         result = await service.add_records(
             dataset=dataset,
@@ -145,13 +138,9 @@ def configure_router():
         name: str,
         search: TextClassificationSearchRequest = None,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        include_metrics: bool = Query(
-            False, description="If enabled, return related record metrics"
-        ),
+        include_metrics: bool = Query(False, description="If enabled, return related record metrics"),
         pagination: RequestPagination = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> TextClassificationSearchResults:
@@ -191,7 +180,6 @@ def configure_router():
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
         )
         result = service.search(
             dataset=dataset,
@@ -205,9 +193,7 @@ def configure_router():
         return TextClassificationSearchResults(
             total=result.total,
             records=result.records,
-            aggregations=TextClassificationSearchAggregations.parse_obj(result.metrics)
-            if result.metrics
-            else None,
+            aggregations=TextClassificationSearchAggregations.parse_obj(result.metrics) if result.metrics else None,
         )
 
     def scan_data_response(
@@ -239,9 +225,7 @@ def configure_router():
                     )
                 ) + "\n"
 
-        return StreamingResponseWithErrorHandling(
-            stream_generator(data_stream), media_type="application/json"
-        )
+        return StreamingResponseWithErrorHandling(stream_generator(data_stream), media_type="application/json")
 
     @router.post(
         f"{base_endpoint}/data",
@@ -254,9 +238,7 @@ def configure_router():
         common_params: CommonTaskHandlerDependencies = Depends(),
         id_from: Optional[str] = None,
         limit: Optional[int] = Query(None, description="Limit loaded records", gt=0),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> StreamingResponse:
@@ -290,7 +272,6 @@ def configure_router():
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
         )
 
         data_stream = map(
@@ -320,23 +301,18 @@ def configure_router():
         name: str,
         common_params: CommonTaskHandlerDependencies = Depends(),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> List[LabelingRule]:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
 
-        return [
-            LabelingRule.parse_obj(rule) for rule in service.get_labeling_rules(dataset)
-        ]
+        return [LabelingRule.parse_obj(rule) for rule in service.list_labeling_rules(dataset)]
 
     @deprecate_endpoint(
         path=f"{new_base_endpoint}/labeling/rules",
@@ -351,19 +327,16 @@ def configure_router():
         name: str,
         rule: CreateLabelingRule,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> LabelingRule:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
 
         rule = ServiceLabelingRule(
@@ -388,26 +361,21 @@ def configure_router():
     async def compute_rule_metrics(
         name: str,
         query: str,
-        labels: Optional[List[str]] = Query(
-            None, description="Label related to query rule", alias="label"
-        ),
+        labels: Optional[List[str]] = Query(None, description="Label related to query rule", alias="label"),
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> LabelingRuleMetricsSummary:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
 
-        return service.compute_rule_metrics(dataset, rule_query=query, labels=labels)
+        return service.compute_labeling_rule(dataset, rule_query=query, labels=labels)
 
     @deprecate_endpoint(
         path=f"{new_base_endpoint}/labeling/rules/metrics",
@@ -421,9 +389,7 @@ def configure_router():
     async def compute_dataset_rules_metrics(
         name: str,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> DatasetLabelingRulesMetricsSummary:
@@ -432,9 +398,9 @@ def configure_router():
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
-        metrics = service.compute_overall_rules_metrics(dataset)
+        metrics = service.compute_all_labeling_rules(dataset)
         return DatasetLabelingRulesMetricsSummary.parse_obj(metrics)
 
     @deprecate_endpoint(
@@ -448,19 +414,16 @@ def configure_router():
         name: str,
         query: str,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> None:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
 
         service.delete_labeling_rule(dataset, rule_query=query)
@@ -478,24 +441,18 @@ def configure_router():
         name: str,
         query: str,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> LabelingRule:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
-        )
-        rule = service.find_labeling_rule(
-            dataset,
-            rule_query=query,
+            as_dataset_class=TextClassificationDataset,
         )
+        rule = service.find_labeling_rule(dataset, rule_query=query)
         return LabelingRule.parse_obj(rule)
 
     @deprecate_endpoint(
@@ -512,19 +469,16 @@ def configure_router():
         query: str,
         update: UpdateLabelingRule,
         common_params: CommonTaskHandlerDependencies = Depends(),
-        service: TextClassificationService = Depends(
-            TextClassificationService.get_instance
-        ),
+        service: TextClassificationService = Depends(TextClassificationService.get_instance),
         datasets: DatasetsService = Depends(DatasetsService.get_instance),
         current_user: User = Security(auth.get_user, scopes=[]),
     ) -> LabelingRule:
-
         dataset = datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
             workspace=common_params.workspace,
-            as_dataset_class=TasksFactory.get_task_dataset(task_type),
+            as_dataset_class=TextClassificationDataset,
         )
 
         rule = service.update_labeling_rule(
