@@ -32,18 +32,13 @@ from argilla.server.daos.backend.search.model import (
 
 
 class HighlightParser:
-
     _SEARCH_KEYWORDS_FIELD = "search_keywords"
 
     __HIGHLIGHT_PRE_TAG__ = "<@@-ar-key>"
     __HIGHLIGHT_POST_TAG__ = "</@@-ar-key>"
-    __HIGHLIGHT_VALUES_REGEX__ = re.compile(
-        rf"{__HIGHLIGHT_PRE_TAG__}(.+?){__HIGHLIGHT_POST_TAG__}"
-    )
+    __HIGHLIGHT_VALUES_REGEX__ = re.compile(rf"{__HIGHLIGHT_PRE_TAG__}(.+?){__HIGHLIGHT_POST_TAG__}")
 
-    __HIGHLIGHT_PHRASE_PRE_PARSER_REGEX__ = re.compile(
-        rf"{__HIGHLIGHT_POST_TAG__}\s+{__HIGHLIGHT_PRE_TAG__}"
-    )
+    __HIGHLIGHT_PHRASE_PRE_PARSER_REGEX__ = re.compile(rf"{__HIGHLIGHT_POST_TAG__}\s+{__HIGHLIGHT_PRE_TAG__}")
 
     @property
     def search_keywords_field(self) -> str:
@@ -103,32 +98,18 @@ class EsQueryBuilder:
             cls._INSTANCE = cls()
         return cls._INSTANCE
 
-    def _datasets_to_es_query(
-        self, query: Optional[BackendDatasetsQuery] = None
-    ) -> Dict[str, Any]:
+    def _datasets_to_es_query(self, query: Optional[BackendDatasetsQuery] = None) -> Dict[str, Any]:
         if not query:
             return filters.match_all()
 
         query_filters = []
-        if query.owners:
-            owners_filter = filters.terms_filter(
-                "owner.keyword",
-                query.owners,
-            )
-            if query.include_no_owner:
-                query_filters.append(
-                    filters.boolean_filter(
-                        minimum_should_match=1,  # OR Condition
-                        should_filters=[
-                            owners_filter,
-                            filters.boolean_filter(
-                                must_not_query=filters.exists_field("owner")
-                            ),
-                        ],
-                    )
+        if query.workspaces:
+            query_filters.append(
+                filters.terms_filter(
+                    "owner.keyword",  # This will be moved to "workspace.keyword"
+                    query.workspaces,
                 )
-            else:
-                query_filters.append(owners_filter)
+            )
 
         if query.tasks:
             query_filters.append(
@@ -185,18 +166,16 @@ class EsQueryBuilder:
 
     def map_2_es_query(
         self,
-        schema: Optional[Dict[str, Any]] = None,
-        query: Optional[BackendQuery] = None,
-        sort: Optional[SortConfig] = None,
+        schema: Dict[str, Any],
+        query: BackendQuery,
+        sort: SortConfig = SortConfig(),
         exclude_fields: Optional[List[str]] = None,
         include_fields: List[str] = None,
         doc_from: Optional[int] = None,
         highlight: Optional[HighlightParser] = None,
         size: Optional[int] = None,
-        id_from: Optional[str] = None,
-        shuffle: bool = False,
+        search_after_param: Optional[Any] = None,
     ) -> Dict[str, Any]:
-
         if query and query.raw_query:
             es_query = {"query": query.raw_query}
         else:
@@ -206,16 +185,15 @@ class EsQueryBuilder:
                 else {"query": self._search_to_es_query(schema, query)}
             )
 
-        if id_from:
-            es_query["search_after"] = [id_from]
-            sort = SortConfig()  # sort by id as default
+        if search_after_param:
+            es_query["search_after"] = search_after_param
 
-        if shuffle:
+        if sort.shuffle:
             self._setup_random_score(es_query)
-
-        es_sort = self.map_2_es_sort_configuration(schema=schema, sort=sort)
-        if es_sort and not shuffle:
-            es_query["sort"] = es_sort
+        else:
+            es_sort = self.map_2_es_sort_configuration(schema=schema, sort=sort)
+            if es_sort:
+                es_query["sort"] = es_sort
 
         if doc_from:
             es_query["from"] = doc_from
@@ -247,13 +225,8 @@ class EsQueryBuilder:
 
         return es_query
 
-    def map_2_es_sort_configuration(
-        self,
-        schema: Optional[Dict[str, Any]] = None,
-        sort: Optional[SortConfig] = None,
-    ) -> Optional[List[Dict[str, Any]]]:
-
-        if not sort:
+    def map_2_es_sort_configuration(self, schema: Dict[str, Any], sort: SortConfig) -> Optional[List[Dict[str, Any]]]:
+        if not sort.sort_by or sort.shuffle:
             return None
 
         # TODO(@frascuchon): compute valid list from the schema
@@ -280,10 +253,9 @@ class EsQueryBuilder:
         es_sort = []
         for sortable_field in sort.sort_by or [SortableField(id="id")]:
             if valid_fields:
-                if not sortable_field.id.split(".")[0] in valid_fields:
+                if sortable_field.id.split(".")[0] not in valid_fields:
                     raise AssertionError(
-                        f"Wrong sort id {sortable_field.id}. Valid values are: "
-                        f"{[str(v) for v in valid_fields]}"
+                        f"Wrong sort id {sortable_field.id}. Valid values are: " f"{[str(v) for v in valid_fields]}"
                     )
             field = sortable_field.id
             if field == id_field and use_id_keyword:
@@ -326,9 +298,7 @@ class EsQueryBuilder:
             elif isinstance(value, (str, Enum)):
                 key_filter = filters.term_filter(key, value)
             elif isinstance(value, QueryRange):
-                key_filter = filters.range_filter(
-                    field=key, value_from=value.range_from, value_to=value.range_to
-                )
+                key_filter = filters.range_filter(field=key, value_from=value.range_from, value_to=value.range_to)
 
             else:
                 cls._LOGGER.warning(f"Cannot parse query value {value} for key {key}")
