@@ -26,6 +26,7 @@ from argilla.server.errors import (
     ForbiddenOperationError,
     WrongTaskError,
 )
+from argilla.server.schemas.datasets import CreateDatasetRequest, Dataset
 from argilla.server.security.model import User
 
 
@@ -38,19 +39,14 @@ class ServiceBaseDatasetSettings(BaseDatasetSettingsDB):
 
 
 ServiceDataset = TypeVar("ServiceDataset", bound=ServiceBaseDataset)
-ServiceDatasetSettings = TypeVar(
-    "ServiceDatasetSettings", bound=ServiceBaseDatasetSettings
-)
+ServiceDatasetSettings = TypeVar("ServiceDatasetSettings", bound=ServiceBaseDatasetSettings)
 
 
 class DatasetsService:
-
     _INSTANCE: "DatasetsService" = None
 
     @classmethod
-    def get_instance(
-        cls, dao: DatasetsDAO = Depends(DatasetsDAO.get_instance)
-    ) -> "DatasetsService":
+    def get_instance(cls, dao: DatasetsDAO = Depends(DatasetsDAO.get_instance)) -> "DatasetsService":
         if not cls._INSTANCE:
             cls._INSTANCE = cls(dao)
         return cls._INSTANCE
@@ -58,96 +54,49 @@ class DatasetsService:
     def __init__(self, dao: DatasetsDAO):
         self.__dao__ = dao
 
-    def create_dataset(self, user: User, dataset: ServiceDataset) -> ServiceDataset:
-        user.check_workspace(dataset.owner)
-
+    def create_dataset(self, user: User, dataset: CreateDatasetRequest) -> BaseDatasetDB:
+        dataset.workspace = user.check_workspace(dataset.workspace)
         try:
-            self.find_by_name(
-                user=user, name=dataset.name, task=dataset.task, workspace=dataset.owner
-            )
-            raise EntityAlreadyExistsError(
-                name=dataset.name, type=ServiceDataset, workspace=dataset.owner
-            )
+            self.find_by_name(user=user, name=dataset.name, task=dataset.task, workspace=dataset.workspace)
+            raise EntityAlreadyExistsError(name=dataset.name, type=ServiceDataset, workspace=dataset.workspace)
         except WrongTaskError:  # Found a dataset with same name but different task
-            raise EntityAlreadyExistsError(
-                name=dataset.name, type=ServiceDataset, workspace=dataset.owner
-            )
+            raise EntityAlreadyExistsError(name=dataset.name, type=ServiceDataset, workspace=dataset.workspace)
         except EntityNotFoundError:
             # The dataset does not exist -> create it !
             date_now = datetime.utcnow()
-            dataset.created_by = user.username
-            dataset.created_at = date_now
-            dataset.last_updated = date_now
-            return self.__dao__.create_dataset(dataset)
+
+            new_dataset = BaseDatasetDB.parse_obj(dataset.dict())
+            new_dataset.created_by = user.username
+            new_dataset.created_at = date_now
+            new_dataset.last_updated = date_now
+
+            return self.__dao__.create_dataset(new_dataset)
 
     def find_by_name(
         self,
         user: User,
         name: str,
+        workspace: str,
         as_dataset_class: Type[ServiceDataset] = ServiceBaseDataset,
         task: Optional[str] = None,
-        workspace: Optional[str] = None,
     ) -> ServiceDataset:
-        owner = user.check_workspace(workspace)
-
-        if task is None:
-            found_ds = self.__find_by_name_with_superuser_fallback__(
-                user, name=name, owner=owner, as_dataset_class=as_dataset_class
-            )
-            if found_ds:
-                task = found_ds.task
-
-        found_ds = self.__find_by_name_with_superuser_fallback__(
-            user, name=name, owner=owner, task=task, as_dataset_class=as_dataset_class
-        )
-
+        workspace = user.check_workspace(workspace)
+        found_ds = self.__dao__.find_by_name(name=name, workspace=workspace, as_dataset_class=as_dataset_class)
         if found_ds is None:
             raise EntityNotFoundError(name=name, type=ServiceDataset)
-        if found_ds.owner and owner and found_ds.owner != owner:
-            raise EntityNotFoundError(
-                name=name, type=ServiceDataset
-            ) if user.is_superuser() else ForbiddenOperationError()
-
-        return cast(ServiceDataset, found_ds)
-
-    def __find_by_name_with_superuser_fallback__(
-        self,
-        user: User,
-        name: str,
-        owner: Optional[str],
-        as_dataset_class: Optional[Type[ServiceDataset]],
-        task: Optional[str] = None,
-    ):
-        found_ds = self.__dao__.find_by_name(
-            name=name, owner=owner, task=task, as_dataset_class=as_dataset_class
-        )
-        if not found_ds and user.is_superuser():
-            try:
-                found_ds = self.__dao__.find_by_name(
-                    name=name, owner=None, task=task, as_dataset_class=as_dataset_class
-                )
-            except WrongTaskError:
-                # A dataset exists in a different workspace and with a different task
-                pass
-        return found_ds
+        elif task and found_ds.task != task:
+            raise WrongTaskError(detail=f"Provided task {task} cannot be applied to dataset")
+        else:
+            return cast(ServiceDataset, found_ds)
 
     def delete(self, user: User, dataset: ServiceDataset):
-        user.check_workspace(dataset.owner)
-        found = self.__find_by_name_with_superuser_fallback__(
-            user=user,
-            name=dataset.name,
-            owner=dataset.owner,
-            task=dataset.task,
-            as_dataset_class=None,
-        )
-        if not found:
-            return
+        dataset = self.find_by_name(user=user, name=dataset.name, workspace=dataset.workspace, task=dataset.task)
 
         if user.is_superuser() or user.username == dataset.created_by:
             self.__dao__.delete_dataset(dataset)
         else:
             raise ForbiddenOperationError(
-                f"You don't have the necessary permissions to delete this dataset. "
+                "You don't have the necessary permissions to delete this dataset. "
                 "Only dataset creators or administrators can delete datasets"
             )
 
@@ -157,16 +106,12 @@ class DatasetsService:
         dataset: ServiceDataset,
         tags: Dict[str, str],
         metadata: Dict[str, Any],
-    ) -> ServiceDataset:
-        found = self.find_by_name(
-            user=user, name=dataset.name, task=dataset.task, workspace=dataset.owner
-        )
+    ) -> Dataset:
+        found = self.find_by_name(user=user, name=dataset.name, task=dataset.task, workspace=dataset.workspace)
 
         dataset.tags = {**found.tags, **(tags or {})}
         dataset.metadata = {**found.metadata, **(metadata or {})}
-        updated = found.copy(
-            update={**dataset.dict(by_alias=True), "last_updated": datetime.utcnow()}
-        )
+        updated = found.copy(update={**dataset.dict(by_alias=True), "last_updated": datetime.utcnow()})
         return self.__dao__.update_dataset(updated)
 
     def list(
@@ -175,17 +120,15 @@ class DatasetsService:
         workspaces: Optional[List[str]],
         task2dataset_map: Dict[str, Type[ServiceDataset]] = None,
     ) -> List[ServiceDataset]:
-        owners = user.check_workspaces(workspaces)
-        return self.__dao__.list_datasets(
-            owner_list=owners, task2dataset_map=task2dataset_map
-        )
+        workspaces = user.check_workspaces(workspaces)
+        return self.__dao__.list_datasets(workspaces=workspaces, task2dataset_map=task2dataset_map)
 
     def close(self, user: User, dataset: ServiceDataset):
-        found = self.find_by_name(user=user, name=dataset.name, workspace=dataset.owner)
+        found = self.find_by_name(user=user, name=dataset.name, workspace=dataset.workspace)
         self.__dao__.close(found)
 
     def open(self, user: User, dataset: ServiceDataset):
-        found = self.find_by_name(user=user, name=dataset.name, workspace=dataset.owner)
+        found = self.find_by_name(user=user, name=dataset.name, workspace=dataset.workspace)
         self.__dao__.open(found)
 
     def copy_dataset(
@@ -197,8 +140,7 @@ class DatasetsService:
         copy_tags: Dict[str, Any] = None,
         copy_metadata: Dict[str, Any] = None,
     ) -> ServiceDataset:
-
-        dataset_workspace = copy_workspace or dataset.owner
+        dataset_workspace = copy_workspace or dataset.workspace
         dataset_workspace = user.check_workspace(dataset_workspace)
 
         self._validate_copy_dataset(name=copy_name, workspace=dataset_workspace)
@@ -206,17 +148,19 @@ class DatasetsService:
         copy_dataset = dataset.copy()
 
         copy_dataset.name = copy_name
+        copy_dataset.workspace = dataset_workspace
         copy_dataset.owner = dataset_workspace
         copy_dataset.created_by = user.username
 
         date_now = datetime.utcnow()
+
         copy_dataset.created_at = date_now
         copy_dataset.last_updated = date_now
         copy_dataset.tags = {**copy_dataset.tags, **(copy_tags or {})}
         copy_dataset.metadata = {
             **copy_dataset.metadata,
             **(copy_metadata or {}),
-            "source_workspace": dataset.owner,
+            "source_workspace": dataset.workspace,
             "copied_from": dataset.name,
         }
 
@@ -228,11 +172,9 @@ class DatasetsService:
         return copy_dataset
 
     def _validate_copy_dataset(self, name: str, workspace: str):
-        found = self.__dao__.find_by_name(name=name, owner=workspace)
+        found = self.__dao__.find_by_name(name=name, workspace=workspace)
         if found:
-            raise EntityAlreadyExistsError(
-                name=found.name, type=found.__class__, workspace=workspace
-            )
+            raise EntityAlreadyExistsError(name=found.name, type=found.__class__, workspace=workspace)
 
     async def get_settings(
         self,
@@ -245,10 +187,12 @@ class DatasetsService:
             raise EntityNotFoundError(name=dataset.name, type=class_type)
         return class_type.parse_obj(settings.dict())
 
+    def raw_dataset_update(self, dataset):
+        self.__dao__.update_dataset(dataset)
+
     async def save_settings(
         self, user: User, dataset: ServiceDataset, settings: ServiceDatasetSettings
     ) -> ServiceDatasetSettings:
-
         self.__dao__.save_settings(dataset=dataset, settings=settings)
         return settings
 
